@@ -16,9 +16,14 @@
 #include "attica_export.h"
 #include "provider.h"
 
+/**
+ * The Attica namespace,
+ */
 namespace Attica
 {
 /**
+ * @class ProviderManager providermanager.h <Attica/ProviderManager>
+ *
  * Attica ProviderManager
  *
  * This class is the primary access to Attica's functions.
@@ -63,7 +68,7 @@ public:
     Q_DECLARE_FLAGS(ProviderFlags, ProviderFlag)
 
     ProviderManager(const ProviderFlags &flags = NoFlags);
-    ~ProviderManager();
+    ~ProviderManager() override;
 
     /**
      * Load available providers from configuration
@@ -130,14 +135,6 @@ public:
      */
     QList<Provider> providers() const;
 
-#if ATTICA_ENABLE_DEPRECATED_SINCE(5, 23)
-    /**
-     * @deprecated Since 5.23, use contains(const QUrl&)
-     */
-    ATTICA_DEPRECATED_VERSION(5, 23, "Use ProviderManager::contains(const QUrl&)")
-    bool contains(const QString &provider) const;
-#endif
-
     /**
      * @returns whether there's a provider with base url @p provider
      */
@@ -160,19 +157,19 @@ Q_SIGNALS:
     void failedToLoad(const QUrl &provider, QNetworkReply::NetworkError error);
 
 private Q_SLOTS:
-    void fileFinished(const QString &url);
-    void authenticate(QNetworkReply *, QAuthenticator *);
-    void proxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *authenticator);
-    void slotLoadDefaultProvidersInternal();
+    ATTICA_NO_EXPORT void fileFinished(const QString &url);
+    ATTICA_NO_EXPORT void authenticate(QNetworkReply *, QAuthenticator *);
+    ATTICA_NO_EXPORT void proxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *authenticator);
+    ATTICA_NO_EXPORT void slotLoadDefaultProvidersInternal();
 
 private:
-    ProviderManager(const ProviderManager &other);
-    ProviderManager &operator=(const ProviderManager &other);
+    ProviderManager(const ProviderManager &other) = delete;
+    ProviderManager &operator=(const ProviderManager &other) = delete;
 
-    void initNetworkAccesssManager();
-    PlatformDependent *loadPlatformDependent(const ProviderFlags &flags);
+    ATTICA_NO_EXPORT void initNetworkAccesssManager();
+    ATTICA_NO_EXPORT PlatformDependent *loadPlatformDependent(const ProviderFlags &flags);
 
-    void parseProviderFile(const QString &xmlString, const QUrl &url);
+    ATTICA_NO_EXPORT void parseProviderFile(const QString &xmlString, const QUrl &url);
 
     class Private;
     Private *const d;
